[![Build Status](https://travis-ci.org/guillaumevincent/git-rename-authors.svg?branch=master)](https://travis-ci.org/guillaumevincent/git-rename-authors)

# git-rename-authors : clean the authors of your git repository

git-rename-authors is an interface to help clean authors and emails a git repository. This is an interface to perform an improved version of the github script : https://help.github.com/articles/changing-author-info/

version 0.1.0

![](screenshot.png?raw=true)


## requirements

 - python 3

**Warning**: This action is destructive to your repository's history. If you're collaborating on a repository with others, it's considered bad practice to rewrite published history. You should only do this in an emergency.


## installing

    pip install git-rename-authors

## License

MIT
